@@ -38,7 +38,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw(
 
 );
-our $VERSION = '1.01';
+our $VERSION = '1.04';
 
 # -----------------------------------------------
 
@@ -576,18 +576,6 @@ Parse the given file and return a hash ref as documented in the previous section
 Return, sorted, the keys of the hash holding extension attributes not recognized
 by any of the above patterns.
 
-=head1 Required Modules
-
-=over 4
-
-=item Carp
-
-=back
-
-=head1 Changes
-
-See Changes.txt.
-
 =head1 Author
 
 C<Data::PABX::ParseLex> was written by Ron Savage I<E<lt>ron@savage.net.auE<gt>>
@@ -597,8 +585,7 @@ Home page: http://savage.net.au/index.html
 
 =head1 Copyright
 
-Australian copyright (c) 2005, Ron Savage. All rights reserved.
-
+Australian copyright (c) 2005, Ron Savage.
 	All Programs of mine are 'OSI Certified Open Source Software';
 	you can redistribute them and/or modify them under the terms of
 	The Artistic License, a copy of which is available at:
